@@ -23,7 +23,7 @@ bufr_descriptors_array* grib_bufr_descriptors_array_new(grib_context* c, size_t
     v = (bufr_descriptors_array*)grib_context_malloc(c, sizeof(bufr_descriptors_array));
     if (!v) {
         grib_context_log(c, GRIB_LOG_ERROR,
-                         "bufr_descriptors_array_new unable to allocate %d bytes\n", sizeof(bufr_descriptors_array));
+                         "bufr_descriptors_array_new unable to allocate %ld bytes\n", sizeof(bufr_descriptors_array));
         return NULL;
     }
     v->context             = c;
@@ -34,7 +34,7 @@ bufr_descriptors_array* grib_bufr_descriptors_array_new(grib_context* c, size_t
     v->number_of_pop_front = 0;
     if (!v->v) {
         grib_context_log(c, GRIB_LOG_ERROR,
-                         "grib_bufr_descriptors_array_new unable to allocate %d bytes\n", sizeof(bufr_descriptor) * size);
+                         "grib_bufr_descriptors_array_new unable to allocate %ld bytes\n", sizeof(bufr_descriptor) * size);
         return NULL;
     }
     return v;
@@ -74,7 +74,7 @@ static bufr_descriptors_array* grib_bufr_descriptors_array_resize_to(bufr_descri
     newv = (bufr_descriptor**)grib_context_malloc_clear(c, newsize * sizeof(bufr_descriptor*));
     if (!newv) {
         grib_context_log(c, GRIB_LOG_ERROR,
-                         "grib_bufr_descriptors_array_resize unable to allocate %d bytes\n", sizeof(bufr_descriptor*) * newsize);
+                         "grib_bufr_descriptors_array_resize unable to allocate %ld bytes\n", sizeof(bufr_descriptor*) * newsize);
         return NULL;
     }
 
@@ -93,7 +93,7 @@ static bufr_descriptors_array* grib_bufr_descriptors_array_resize_to(bufr_descri
 
 static bufr_descriptors_array* grib_bufr_descriptors_array_resize(bufr_descriptors_array* v)
 {
-    const int newsize = v->incsize + v->size;
+    const size_t newsize = v->incsize + v->size;
     return grib_bufr_descriptors_array_resize_to(v, newsize);
 }
 
